@@ -6,7 +6,9 @@ use Test::Builder;
 use Sub::Uplevel qw( uplevel );
 use base qw( Exporter );
 
-our $VERSION = '0.41';
+our $VERSION = '0.43';
+$VERSION = eval $VERSION;
+
 our @EXPORT = qw(dies_ok lives_ok throws_ok lives_and);
 
 my $Tester = Test::Builder->new;
@@ -337,40 +339,13 @@ The test description is optional, but recommended.
 
 =cut
 
-my $is_test2 = $INC{'Test2/Global.pm'} || $INC{'Test2/API.pm'} || $INC{'Test2/Context.pm'};
-my $is_stream = $INC{'Test/Stream/Sync.pm'};
-our $LIVES_AND_NAME;
-if ($is_test2) {
-    Test2::Global::test2_stack()->top->filter(sub {
-        my ($hub, $e) = @_;
-        return $e unless defined $LIVES_AND_NAME;
-        return $e unless $e->isa('Test2::Event::Ok');
-        return $e if defined $e->name;
-        $e->set_name($LIVES_AND_NAME);
-        return $e;
-    });
-}
-elsif ($is_stream) {
-    Test::Stream::Sync->stack->top->munge(sub {
-        return unless defined $LIVES_AND_NAME;
-        my ($stream, $e) = @_;
-        return unless $e->isa('Test::Stream::Event::Ok');
-        return if defined $e->name;
-        $e->set_name($LIVES_AND_NAME);
-    });
-}
-
 sub lives_and (&;$) {
     my ( $test, $description ) = @_;
-    if ($is_test2 || $is_stream) {
-        local $LIVES_AND_NAME = $description;
-        eval { $test->() } and return 1;
-    }
-    else {
-        local $Test::Builder::Level = $Test::Builder::Level + 1;
+    {
         my $ok = \&Test::Builder::ok;
         no warnings;
         local *Test::Builder::ok = sub {
+            local $Test::Builder::Level = $Test::Builder::Level + 1;
             $_[2] = $description unless defined $_[2];
             $ok->(@_);
         };
